# DALI-DATASET

Code for working with the DALI dataset.
You can download the dataset at [zenodo](https://zenodo.org/record/2577915) and find a tutorial of and more information of how to use this code at [github/gabolsgabs](https://github.com/gabolsgabs/DALI).

Copyright © Ircam 2018
This package is distributed under the Academic Free License ("AFL") v. 3.0.
For more information about the license read the LICENSE.txt
